//Задаем путь к точкам обмена сообщениями 
function [messages,..
          pathToMessagePoint]=ReadMessageFromPointFile(MessageFilePointName,..//Имя точки обмена сообщениями
                                                       messagesHeader,..//Заголовок сообщений (с соответствующим расширением)
                                                       waiting,..//Ожидание сообщения 
                                                       deleting..//надо ли удалять файл, на который пришло сообщение
                                                       )
    //Проверяем число аргументов
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Function ReadMessageFromPointFile takes 2, 3 or 4 arguments');
    elseif nArg == 2 then
        deleting = %t;//По умолчанию файл удаляем
    end
    select nArg
    case 2 then
        waiting = %f;//По умолчанию файл не ждем
        deleting = %t;//По умолчанию файл удаляем
    case 3 then
        deleting = %t;//По умолчанию файл удаляем
    end
    
    //Проверяем аргумент
    if (type(MessageFilePointName) ~= 10) ||..
       (size(MessageFilePointName,'*') ~= 1) then
        error('The argument MessageFilePointName of function ReadMessageFromPointFile must be scalar string');
    end
    if (type(messagesHeader) ~= 10) ||..
       (size(messagesHeader,'*') ~= 1) then
        error('The argument messagesHeader of function ReadMessageFromPointFile must be scalar string');
    end
    if (type(deleting) ~= 4) || (size(deleting,'*') > 1) then
        error('The argument deleting of function ReadMessageFromPointFile must be scalar boolean');
    end
    
    //Проверяем, зарегистрирована ли точка обмена сообщениями
    [regRezult,..
     pathToMessagePoint]=isRegisteredMessageFilePoint(MessageFilePointName);
    if ~regRezult then
        messages = [];
        error('The file message point ' + MessageFilePointName + ' is not registered');
    end
    
    //Считываем сообщения
    pathToReadMessageFile = fullfile(pathToMessagePoint,messagesHeader);
    if waiting then
        //Ждем появления файла сообщения
        while isempty(fileinfo(pathToReadMessageFile))
        end
    elseif isempty(fileinfo(pathToReadMessageFile)) then
		messages = [];
		return;
	end
    messages = mgetl(pathToReadMessageFile);//Считываем строки
    
    //Удаляем файл при необходимости
    if deleting && (~deletefile(pathToReadMessageFile)) then
        error('Cannot deleting message file ' + messagesHeader);
    end
endfunction
