//Задаем путь к точкам обмена сообщениями 
function [err,..
          pathToMessagePoint]=WriteMessageToPointFile(MessageFilePointName,..//Имя точки обмена сообщениями
                                                      messagesHeader,..//Заголовок сообщений (с соответствующим расширением) 
                                                      messages,..//Записываемые сообщения
                                                      reWrite..//Переписываем ли файл
                                                      )
    //Проверяем число аргументов
    nArg = argn(2);//Число аргументов
    if nArg < 3 then
        error('Function WriteMessageFromPointFile takes 3 or 4 arguments');
    elseif nArg == 3 then
        reWrite = %f;//По умолчанию дозаписываем в файл 
    end
    
    //Проверяем аргумент
    if (type(MessageFilePointName) ~= 10) ||..
       (size(MessageFilePointName,'*') ~= 1) then
        error('The argument MessageFilePointName of function WriteMessageFromPointFile must be scalar string');
    end
    if (type(messagesHeader) ~= 10) || (size(messagesHeader,'*') ~= 1) then
        error('The argument messagesHeader of function WriteMessageFromPointFile must be scalar string');
    end
    if type(messages) ~= 10 then
        error('The argument messages of function WriteMessageFromPointFile must be matrix of string');
    end
    if (type(reWrite) ~= 4) || (size(reWrite,'*') ~= 1) then
        error('The argument reWrite of function WriteMessageFromPointFile must be scalar boolean');
    end
    
    //Проверяем, зарегистрирована ли точка обмена сообщениями
    [regRezult,..
     pathToMessagePoint]=isRegisteredMessageFilePoint(MessageFilePointName);
    if ~regRezult then
        err = 2;
        error('The file message point ' + MessageFilePointName + ' is not registered');
    end
    
    //Приводим к матрице-столбцу
    messages = matrix(messages,-1,1);
    
    //Записываем сообщения
    pathToWriteMessageFile = fullfile(pathToMessagePoint,messagesHeader);
    if reWrite then//Режим открытия файла
        modeWriteMessageFile = 'wt';
    else
        modeWriteMessageFile = 'at';
    end
    WriteMessageFile = mopen(pathToWriteMessageFile,modeWriteMessageFile);//Открываем файл сообщений
    if ~mputl(messages,WriteMessageFile) then
        err = 1;
        error('Cannot writing messages to message file ' + messagesHeader);
    else
        err = 0;
    end
    mclose(WriteMessageFile);//Закрываем файл сообщений
endfunction
